@@ -38,17 +38,17 @@ class StringExpressionWriter : public AbstractExpressionVisitor
     public:
         explicit StringExpressionWriter(const Object* o);
         
-        virtual QVariant visit(const None* var) override;
-        virtual QVariant visit(const Ci* var) override;
-        virtual QVariant visit(const Cn* var) override;
-        virtual QVariant visit(const Container* var) override;
-        virtual QVariant visit(const Operator* var) override;
-        virtual QVariant visit(const Vector* var) override;
-        virtual QVariant visit(const List* l) override;
-        virtual QVariant visit(const Matrix* m) override;
-        virtual QVariant visit(const MatrixRow* mr) override;
-        virtual QVariant visit(const Apply* a) override;
-        virtual QVariant visit(const CustomObject* c) override;
+        QVariant visit(const None* var) override;
+        QVariant visit(const Ci* var) override;
+        QVariant visit(const Cn* var) override;
+        QVariant visit(const Container* var) override;
+        QVariant visit(const Operator* var) override;
+        QVariant visit(const Vector* var) override;
+        QVariant visit(const List* l) override;
+        QVariant visit(const Matrix* m) override;
+        QVariant visit(const MatrixRow* mr) override;
+        QVariant visit(const Apply* a) override;
+        QVariant visit(const CustomObject* c) override;
         
         QVariant result() const override { return m_result; }
         
