@@ -112,7 +112,7 @@ void Plotter3DES::initGL()
 
         "void main(void)\n"
         "{\n"
-        "   float w = 10.*gl_FragCoord.w;\n"
+        "   highp float w = 10.*gl_FragCoord.w;\n"
         "   highp vec4 zvec = vec4(w, w, w, 1.0);"
         "   gl_FragColor = mix(color, zvec, vec4(.5,.5,.5,1.));\n"
         "}"
@@ -512,8 +512,12 @@ bool Plotter3DES::save(const QUrl& url)
         QPrinter printer;
         printer.setOutputFormat(QPrinter::PdfFormat);
         printer.setOutputFileName(path);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         printer.setPaperSize(px.size(), QPrinter::DevicePixel);
-        printer.setPageMargins(0,0,0,0, QPrinter::DevicePixel);
+#else
+#pragma "port printer.setPaperSize";
+#endif
+        printer.setPageMargins(QMarginsF(0,0,0,0));
         QPainter painter;
         painter.begin(&printer);
         painter.drawImage(QPoint(0,0), px);
